Wikimedia Foundation Blog company blog
How we made editing Wikipedia twice as fast
Over the past six months we deployed a new technology that sped up Wikipedia’s backend application, reducing the median page-saving time for editors from about 7.5 seconds to 2.5 seconds.
- Points
- 339
- HN comments
- 132
- Submissions
- 1
- Cited by
- 0 commenters
Web & FrontendSystems & Performance2014
On Hacker News
| Submitted | Title on HN | Points | Comments |
|---|---|---|---|
| Dec 30, 2014 | How we made editing Wikipedia twice as fast by ecaron | 339 | 132 |